.. _class-Format:

``Format`` classes
==================

Interface for formats
---------------------

.. doxygenclass:: chemfiles::Format
    :members:

Implemented formats
-------------------

These classes implement the format interface defined previously.

.. doxygenclass:: chemfiles::XYZFormat

.. doxygenclass:: chemfiles::PDBFormat

.. doxygenclass:: chemfiles::AmberNetCDFFormat

.. doxygenclass:: chemfiles::TNGFormat

.. doxygenclass:: chemfiles::LAMMPSDataFormat

.. doxygenclass:: chemfiles::TinkerFormat

.. doxygenclass:: chemfiles::Molfile

.. doxygenenum:: chemfiles::MolfileFormat
